@@ -23,6 +23,8 @@ var CommandTypes = []CommandType{ //nolint: deadcode
 	ESCAPE,
 	ILLEGAL,
 	LEFT,
+	PAGEUP,
+	PAGEDOWN,
 	RIGHT,
 	SET,
 	OUTPUT,
@@ -60,6 +62,8 @@ var CommandFuncs = map[CommandType]CommandFunc{
 	UP:        ExecuteKey(input.ArrowUp),
 	TAB:       ExecuteKey(input.Tab),
 	ESCAPE:    ExecuteKey(input.Escape),
+	PAGEUP:    ExecuteKey(input.PageUp),
+	PAGEDOWN:  ExecuteKey(input.PageDown),
 	HIDE:      ExecuteHide,
 	REQUIRE:   ExecuteRequire,
 	SHOW:      ExecuteShow,
