@@ -67,6 +67,8 @@ const (
 	PADDING        = "PADDING"
 	THEME          = "THEME"
 	LOOP_OFFSET    = "LOOP_OFFSET" //nolint:revive
+	PAGEUP         = "PAGEUP"
+	PAGEDOWN       = "PAGEDOWN"
 )
 
 var keywords = map[string]TokenType{
@@ -86,6 +88,8 @@ var keywords = map[string]TokenType{
 	"Left":          LEFT,
 	"Right":         RIGHT,
 	"Up":            UP,
+	"PageUp":        PAGEUP,
+	"PageDown":      PAGEDOWN,
 	"Tab":           TAB,
 	"Escape":        ESCAPE,
 	"End":           END,
@@ -124,7 +128,7 @@ func IsSetting(t TokenType) bool {
 func IsCommand(t TokenType) bool {
 	switch t {
 	case TYPE, SLEEP,
-		UP, DOWN, RIGHT, LEFT,
+		UP, DOWN, RIGHT, LEFT, PAGEUP, PAGEDOWN,
 		ENTER, BACKSPACE, DELETE, TAB,
 		ESCAPE, HOME, INSERT, END, CTRL:
 		return true
