@@ -7,6 +7,6 @@ const defaultShell = bash
 
 func defaultShellWithArgs() []string {
 	return []string{
-		"bash", "--login",
+		"sh",
 	}
 }
