@@ -2,6 +2,7 @@ package main
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"math"
 	"os"
@@ -49,7 +50,7 @@ const (
 	defaultFontSize      = 22
 	defaultTypingSpeed   = 50 * time.Millisecond
 	defaultLineHeight    = 1.0
-	defaultLetterSpacing = 0
+	defaultLetterSpacing = 1.0
 	fontsSeparator       = ","
 )
 
@@ -88,7 +89,8 @@ func New() VHS {
 
 	opts := DefaultVHSOptions()
 	path, _ := launcher.LookPath()
-	u := launcher.New().Leakless(false).Bin(path).MustLaunch()
+	enableNoSandbox := os.Getenv("VHS_NO_SANDBOX") != ""
+	u := launcher.New().Leakless(false).Bin(path).NoSandbox(enableNoSandbox).MustLaunch()
 	browser := rod.New().ControlURL(u).MustConnect()
 	page := browser.MustPage(fmt.Sprintf("http://localhost:%d", port))
 
@@ -131,6 +133,10 @@ func (vhs *VHS) Setup() {
 		MustInput(shellCommand).
 		MustType(input.Enter)
 
+	vhs.Page.MustElement("textarea").
+		MustInput(vhs.Options.Shell.Clear).
+		MustType(input.Enter)
+
 	// Apply options to the terminal
 	// By this point the setting commands have been executed, so the `opts` struct is up to date.
 	vhs.Page.MustEval(fmt.Sprintf("() => { term.options = { fontSize: %d, fontFamily: '%s', letterSpacing: %f, lineHeight: %f, theme: %s } }",
@@ -197,6 +203,10 @@ func (vhs *VHS) Render() error {
 
 // Apply Loop Offset by modifying frame sequence
 func (vhs *VHS) ApplyLoopOffset() error {
+	if vhs.totalFrames <= 0 {
+		return errors.New("no frames")
+	}
+
 	loopOffsetPercentage := vhs.Options.LoopOffset
 
 	// Calculate # of frames to offset from LoopOffset percentage
